<?php
/**
 * Theme Option
 *
 * @since 1.0.0
 */
$wp_customize->add_panel(
    'better_health_theme_options',
    array(
        'priority' => 7,
        'capability' => 'edit_theme_options',
        'theme_supports' => '',
        'title' => esc_html__('Theme Option', 'better-health'),
    )
);

/*-------------------------------------------------------------------------------------------*/
/**
 * Hide Static page in Home page
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_front_page_option',
    array(
        'title' => esc_html__('Front Page Options', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 6,
    )
);

/**
 *   Show/Hide Static page/Posts in Home page
 */
$wp_customize->add_setting(
    'better_health_front_page_hide_option',
    array(
        'default' => $default['better_health_front_page_hide_option'],
        'sanitize_callback' => 'better_health_sanitize_checkbox',
    )
);
$wp_customize->add_control('better_health_front_page_hide_option',
    array(
        'label' => esc_html__('Hide Blog Posts or Static Page on Front Page', 'better-health'),
        'section' => 'better_health_front_page_option',
        'type' => 'checkbox',
        'priority' => 10
    )
);



/*-------------------------------------------------------------------------------------------*/
/**
 * Hide Search Button
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_search_button_option',
    array(
        'title' => esc_html__('Hide Search Button Options', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 6,
    )
);

/**
 *   Show/Hide Search Button
 */
$wp_customize->add_setting(
    'better_health_search_button_hide_option',
    array(
        'default' => $default['better_health_search_button_hide_option'],
        'sanitize_callback' => 'better_health_sanitize_checkbox',
    )
);
$wp_customize->add_control('better_health_search_button_hide_option',
    array(
        'label' => esc_html__('Hide Search Button', 'better-health'),
        'section' => 'better_health_search_button_option',
        'type' => 'checkbox',
        'priority' => 10
    )
);

/*-------------------------------------------------------------------------------------------*/
/**
 * Breadcrumb Options
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_breadcrumb_option',
    array(
        'title' => esc_html__('Breadcrumb Options', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 6,
    )
);

/**
 * Breadcrumb Option
 */
$wp_customize->add_setting(
    'better_health_breadcrumb_setting_option',
    array(
        'default' => $default['better_health_breadcrumb_setting_option'],
        'sanitize_callback' => 'better_health_sanitize_select',

    )
);
$hide_show_breadcrumb_option = better_health_show_breadcrumb_option();
$wp_customize->add_control('better_health_breadcrumb_setting_option',
    array(
        'label' => esc_html__('Breadcrumb Options', 'better-health'),
        'description'   => sprintf( esc_html__( 'Advanced: Requires %1$sBreadcrumb NavXT%2$s plugin','better-health'), '<a href="https://wordpress.org/plugins/breadcrumb-navxt/" target="_blank">','</a>' ),
        'section' => 'better_health_breadcrumb_option',
        'choices' => $hide_show_breadcrumb_option,
        'type' => 'select',
        'priority' => 10
    )
);


  /**
     *   Show/Hide Breadcrumb in Home page
     */
    $wp_customize->add_setting(
        'better_health_hide_breadcrumb_front_page_option',
        array(
                'default' => $default['better_health_hide_breadcrumb_front_page_option'],
                'sanitize_callback' => 'better_health_sanitize_checkbox',
             )
    );
    $wp_customize->add_control('better_health_hide_breadcrumb_front_page_option',
        array(
                'label' => esc_html__('Show/Hide Breadcrumb in Home page', 'better-health'),
                'section' => 'better_health_breadcrumb_option',
                'type' => 'checkbox',
                'priority' => 10
             )
    );

  
/*-------------------------------------------------------------------------------------------*/
    /**
     * Button Design
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'better_health_button_design_option',
        array(
                'title'     => esc_html__( 'Button Design','better-health'),
                'panel'     => 'better_health_theme_options',
                'priority'  => 6,
             )
    );

    /**
     * Button Design
     */
    $wp_customize->add_setting(
        'better_health_button_design_layout_option',
        array(
                'default'           => $default['better_health_button_design_layout_option'],
                'sanitize_callback' => 'better_health_sanitize_select',
                'transport' => 'refresh'
              )
    );
    $button_design_option = better_health_button_design_option();
    $wp_customize->add_control('better_health_button_design_layout_option',
        array(
                'label'      => esc_html__('Button Design','better-health'),
                'section'   => 'better_health_button_design_option',
                'type'      => 'select',
                'choices'   => $button_design_option,
                'priority'  => 11
             )
    );

    /*-------------------------------------------------------------------------------------------*/
    /**
     * Pagination Options
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'better_health_pagination_option',
        array(
                'title'     => esc_html__('Pagination Options','better-health'),
                'panel'     => 'better_health_theme_options',
                'priority'  => 12,
             )
    );

    /**
     *Pagination Options
     */
    $wp_customize->add_setting(
        'better_health_post_pagination_option',
        array(
                'default'           =>  $default['better_health_post_pagination_option'],
                'sanitize_callback' => 'sanitize_text_field',
                'transport' => 'refresh'
             )
    );
    $pagination_option = better_health_pagination_option();
    $wp_customize->add_control('better_health_post_pagination_option',
        array(
                'label'      => esc_html__('Pagination Options','better-health'),
                'description'    => sprintf( esc_html__( 'Blog and Archive Pages Pagination', 'better-health' )),
                'section'   => 'better_health_pagination_option',
                'type'      => 'select',
                'choices'   => $pagination_option,
                'priority'  => 12
             )
    );



/*-------------------------------------------------------------------------------------------*/
/**
 * Search Placeholder
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_search_option',
    array(
        'title' => esc_html__('Search', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 12,
    )
);

/**
 *Search Placeholder
 */
$wp_customize->add_setting(
    'better_health_post_search_placeholder_option',
    array(
        'default' => $default['better_health_post_search_placeholder_option'],
        'sanitize_callback' => 'sanitize_text_field',

    )
);

$wp_customize->add_control('better_health_post_search_placeholder_option',
    array(
        'label' => esc_html__('Search Placeholder', 'better-health'),
        'section' => 'better_health_search_option',
        'type' => 'text',
        'priority' => 10
    )
);


/*-------------------------------------------------------------------------------------------*/
/**
 * Woocommerce Store  Text
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_store_text_option',
    array(
        'title' => esc_html__('Woocomeerce Store Text', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 12,
    )
);

/**
 * Woocommerce Store  Text
 */
$wp_customize->add_setting(
    'better_health_post_store_text_option',
    array(
        'default' => $default['better_health_post_store_text_option'],
        'sanitize_callback' => 'sanitize_text_field',

    )
);

$wp_customize->add_control('better_health_post_store_text_option',
    array(
        'label' => esc_html__('Woocommerce Store Text', 'better-health'),
        'section' => 'better_health_store_text_option',
        'type' => 'text',
        'priority' => 10
    )
);





 /*-------------------------------------------------------------------------------------------*/
    /**
     * Contact Us
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'better_health_contact_us_option',
        array(
                'title' => esc_html__('Contact Us Options', 'better-health'),
                'panel' => 'better_health_theme_options',
                'priority' => 12,
              )
    );

    /**
     *Contact Us Working Hours
     */
    $wp_customize->add_setting(
        'better_health_working_hours_option',
        array(
                'default' => $default['better_health_working_hours_option'],
                'sanitize_callback' => 'wp_kses_post',

              )
    );

    $wp_customize->add_control('better_health_working_hours_option',
        array(
                'label' => esc_html__('Working Hours', 'better-health'),
                'description'   => sprintf( esc_html__( 'Insert Working Hours with html tag.[It will work only on Contact Us Template]','better-health')),
                'section' => 'better_health_contact_us_option',
                'type' => 'textarea',
                'priority' => 10
              )
    );


    /**
     *Contact Information
     */
    $wp_customize->add_setting(
        'better_health_contact_info_option',
        array(
                'default' => $default['better_health_contact_info_option'],
                'sanitize_callback' => 'wp_kses_post',

              )
    );

    $wp_customize->add_control('better_health_contact_info_option',
        array(
                'label' => esc_html__('Connect With Us', 'better-health'),
                'description'   => sprintf( esc_html__( 'Insert Contact Info with html tag.[It will work only on Contact Us Template]','better-health')),
                'section' => 'better_health_contact_us_option',
                'type' => 'textarea',
                'priority' => 10
              )
    );


    /**
     *Contact Us Google Map Iframe
     */
    $wp_customize->add_setting(
        'better_health_googlemap_option',
        array(
                'default' => $default['better_health_googlemap_option'],
                'sanitize_callback' => 'better_health_sanitize_iframe',

              )
    );

    $wp_customize->add_control('better_health_googlemap_option',
        array(
                'label' => esc_html__('Google Map Iframe', 'better-health'),
                'description'   => sprintf( esc_html__( 'Insert Google Map Iframe.[It will work only on Contact Us Template]','better-health')),
                'section' => 'better_health_contact_us_option',
                'type' => 'textarea',
                'priority' => 10
              )
    );



/*-------------------------------------------------------------------------------------------*/
/**
 * Hide Appointment 
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_appointment_option',
    array(
        'title' => esc_html__('Appointment Options', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 6,
    )
);


/**
 * Appointment Button Text
 */
$wp_customize->add_setting(
    'better_health_post_appointment_button_text',
    array(
        'default' => $default['better_health_post_appointment_button_text'],
        'sanitize_callback' => 'sanitize_text_field',

    )
);

$wp_customize->add_control('better_health_post_appointment_button_text',
    array(
        'label' => esc_html__('Appointment Button Text', 'better-health'),
        'section' => 'better_health_appointment_option',
        'type' => 'text',
        'priority' => 10
    )
);


/**
 *Appointment Shortcode Field
 */
$wp_customize->add_setting(
    'better_health_appointment_shortcode_field',
    array(
        'default' => $default['better_health_appointment_shortcode_field'],
        'sanitize_callback' => 'wp_kses_post',

    )
);

$wp_customize->add_control('better_health_appointment_shortcode_field',
    array(
        'label' => esc_html__('Appointment Shortcode From Contact Form', 'better-health'),
        'description' => sprintf( esc_html__('Note: Please Create Appointment Form Using Contact Form 7 And Paste Shortcode Here', 'better-health')),
       'section' => 'better_health_appointment_option',
        'type' => 'text',
        'priority' => 10
    )
);




/*-------------------------------------------------------------------------------------------*/
/**
 * Reset Options
 *
 * @since 1.0.0
 */
$wp_customize->add_section(
    'better_health_reset_option',
    array(
        'title' => esc_html__('Reset Options', 'better-health'),
        'panel' => 'better_health_theme_options',
        'priority' => 14,
    )
);

/**
 * Reset Option
 */
$wp_customize->add_setting(
    'better_health_color_reset_option',
    array(
        'default' => $default['better_health_color_reset_option'],
        'sanitize_callback' => 'better_health_sanitize_select',
        'transport' => 'postMessage'
    )
);
$reset_option = better_health_reset_option();
$wp_customize->add_control('better_health_color_reset_option',
    array(
        'label' => esc_html__('Reset Fonts/Color Options', 'better-health'),
        'description' => sprintf( esc_html__('Caution: Reset theme settings according to the given options. Refresh the page after saving to view the effects', 'better-health')),
        'section' => 'better_health_reset_option',
        'type' => 'select',
        'choices' => $reset_option,
        'priority' => 20
    )
);