<?php
if (!class_exists('Better_Health_Hero_Widget'))
{
    class Better_Health_Hero_Widget extends WP_Widget
    {

        private function defaults()
        {
            $defaults = array(
                'title' => esc_html__('Better Health HTML Template. Buy this theme.', 'better-health'),
                'description' => esc_html__('Create beautiful, unique websites with impact full landing pages and banners.', 'better-health'),
                'button-text' => esc_html__('Get Started!', 'better-health'),
                'button-text-link' => '#'
               );

            return $defaults;
        }

        public function __construct()
        {
            parent::__construct(
                'better-health-hero-widget',
                esc_html__('Better Health Hero Widget', 'better-health'),
                array('description' => esc_html__('Better Health Hero Section', 'better-health'))
            );
        }

        public function widget($args, $instance)
        {
            if (!empty($instance)) {
                $instance = wp_parse_args((array)$instance, $this->defaults());
                $title = apply_filters('widget_title', !empty($instance['title']) ? esc_html($instance['title']) : '', $instance, $this->id_base);
                $description= wp_kses_post($instance['description']);
                $button_text = esc_html($instance['button-text']);
                $button_url = esc_url($instance['button-text-link']);
                echo $args['before_widget'];
                ?>
                <section id="section10" class="section-10-background">
                    <div class="container">
                        <div class="row">
                            <div class="col-sm-8 col-md-8">
                                <div class="section-10-box-text-cont">
                                    <h3><?php echo  $title ; ?></h3>
                                    <p><?php echo $description; ?></p>
                                </div>
                            </div>
                            <?php if(!empty($button_text)){ ?>
                            <div class="col-sm-4 col-md-4">
                                <div class="section-10-btn-cont">
                                    <a href="<?php echo $button_url ; ?>" class="btn btn-seconday wow tada"><?php echo  $button_text; ?></a>
                                </div>
                            </div>
                         <?php } ?>   
                        </div>
                    </div>
                </section>
                <?php
                echo $args['after_widget'];
            }
        }

        public function update($new_instance, $old_instance)
        {
            $instance = $old_instance;
            $instance['title'] = sanitize_text_field($new_instance['title']);
            $instance['description'] = wp_kses_post($new_instance['description']);
            $instance['button-text'] = sanitize_text_field($new_instance['button-text']);
            $instance['button-text-link'] = esc_url_raw($new_instance['button-text-link']);
            return $instance;
        }

        public function form($instance)
        {
            $instance = wp_parse_args((array )$instance, $this->defaults());
            $title = esc_attr($instance['title']);
            $description= wp_kses_post($instance['description']);
            $button_text = esc_attr($instance['button-text']);
            $button_url = esc_url($instance['button-text-link']);
            ?>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><strong><?php esc_html_e('Title', 'better-health'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" value="<?php echo  $title; ?>">
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('description' ) ); ?>"><strong><?php esc_html_e('Description', 'better-health'); ?></strong></label><br/>
                <textarea rows="8" name="<?php echo esc_attr( $this->get_field_name('description') ); ?>" id="<?php echo esc_attr( $this->get_field_id('description' ) ); ?>" class="widefat"><?php echo $description; ?></textarea>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('button-text') ); ?>"><strong><?php esc_html_e('Button Text', 'better-health'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('button-text') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('button-text') ); ?>" value="<?php echo $button_text; ?>">
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('button-text-link') ); ?>"><strong><?php esc_html_e('Button Link', 'better-health'); ?></strong></label><br/>
                <input type="url" name="<?php echo esc_attr( $this->get_field_name('button-text-link') ); ?>" class="widefat"  id="<?php echo esc_attr( $this->get_field_id('button-text-link') ); ?>" value="<?php echo $button_url; ?>">
            </p>
            <?php
        }
    }

}

add_action( 'widgets_init', 'better_health_hero_widget' );
function better_health_hero_widget(){
    register_widget( 'Better_Health_Hero_Widget' );

}















