<?php
/**
 * Define some custom classes for quality-construction-pro.
 *
 * https://codex.wordpress.org/Class_Reference/WP_Customize_Control
 *
 * @package Canyon Themes
 * @subpackage Quality Construction
 * @since 1.0.0
 */

if (class_exists('WP_Customize_Control')) {

    /**
     * A class to create a dropdown for all categories in your wordpress site
     *
     * @since 1.0.0
     * public
     */
    class Quality_Construction_Customize_Category_Control extends WP_Customize_Control
    {

        /**
         * Render the control's content.
         *
         * @return void
         * @since 1.0.0
         */
        public function render_content()
        {
            $dropdown = wp_dropdown_categories(
                array(
                        'name' => '_customize-dropdown-categories-' . $this->id,
                        'echo' => 0,
                        'show_option_none' => esc_html__('&mdash; Select Category &mdash;', 'quality-construction'),
                        'option_none_value' => '0',
                        'selected' => $this->value(),
                     )
            );

            // Hackily add in the data link parameter.
            $dropdown = str_replace('<select', '<select ' . $this->get_link(), $dropdown);

            printf(
                    '<label class="customize-control-select">
                       <span class="customize-control-title">%s</span>
                       <span class="description customize-control-description">%s</span> %s 
                    </label>',
                    $this->label,
                    $this->description,
                    $dropdown
                  );
        }
    }

    /**
     * Select customize control class.
     *
     * @since  1.0.0
     * @splash public
     */
    class Quality_Construction_Select_Control extends WP_Customize_Control
    {
        public $type = 'select';

        public function render_content()
        {

            ?>
            <label>
                <span class="customize-control-title"><?php echo esc_html($this->label); ?></span>
                <span class="description customize-control-description"><?php echo esc_html($this->description); ?></span>
            </label>
            <?php
        }
    }


}


    /**
     * Overlay Color Picker Customizer Control
     *
     * This control adds a second slider for opacity to the stock WordPress color picker,
     * and it includes logic to seamlessly convert between RGBa and Hex color values as
     * opacity is added to or removed from a color.

    /**
     * Official control name.
     */
    class Quality_Construction_Customize_Overlay_Color_Control extends WP_Customize_Control {
        public $type = 'alpha-color';
        /**
         * Add support for palettes to be passed in.
         *
         * Supported palette values are true, false, or an array of RGBa and Hex colors.
         */
        public $palette;
        /**
         * Add support for showing the opacity value on the slider handle.
         */
        public $show_opacity;

        /**
         * Render the control.
         */
        public function render_content() {
            // Process the palette
            if ( is_array( $this->palette ) ) {
                $palette = implode( '|', $this->palette );
            } else {
                // Default to true.
                $palette = ( false === $this->palette || 'false' === $this->palette ) ? 'false' : 'true';
            }
            // Support passing show_opacity as string or boolean. Default to true.
            $show_opacity = ( false === $this->show_opacity || 'false' === $this->show_opacity ) ? 'false' : 'true';
            // Begin the output. ?>
            <label>
                <?php // Output the label and description if they were passed in.
                if ( isset( $this->label ) && '' !== $this->label ) {
                    echo '<span class="customize-control-title">' . sanitize_text_field( $this->label ) . '</span>';
                }
                if ( isset( $this->description ) && '' !== $this->description ) {
                    echo '<span class="description customize-control-description">' . esc_html( $this->description ) . '</span>';
                } ?>
                <input class="alpha-color-control" type="text" data-show-opacity="<?php echo esc_html($show_opacity); ?>" data-palette="<?php echo esc_attr( $palette ); ?>" data-default-color="<?php echo esc_attr( $this->settings['default']->default ); ?>" <?php $this->link(); ?>  />
            </label>
            <?php
        }
    }
