<?php
    /**
     * Theme Option
     *
     * @since 1.0.0
     */
    $wp_customize->add_panel(
        'quality_construction_theme_options',
        array(
                'priority' => 7,
                'capability' => 'edit_theme_options',
                'theme_supports' => '',
                'title' => esc_html__('Theme Option', 'quality-construction'),
             )
    );

    /*-------------------------------------------------------------------------------------------*/
    /**
     * Hide Static page in Home page
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_front_page_option',
        array(
                'title' => esc_html__('Front Page Options', 'quality-construction'),
                'panel' => 'quality_construction_theme_options',
                'priority' => 6,
             )
    );

    /**
     *   Show/Hide Static page/Posts in Home page
     */
    $wp_customize->add_setting(
        'quality_construction_front_page_hide_option',
        array(
                'default' => $default['quality_construction_front_page_hide_option'],
                'sanitize_callback' => 'quality_construction_sanitize_checkbox',
              )
    );
    $wp_customize->add_control('quality_construction_front_page_hide_option',
        array(
                'label' => esc_html__('Hide Blog Posts or Static Page on Front Page', 'quality-construction'),
                'section' => 'quality_construction_front_page_option',
                'type' => 'checkbox',
                'priority' => 10
              )
    );


    /*-------------------------------------------------------------------------------------------*/
    /**
     * Breadcrumb Options
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_breadcrumb_option',
        array(
                'title' => esc_html__('Breadcrumb Options', 'quality-construction'),
                'panel' => 'quality_construction_theme_options',
                'priority' => 6,
             )
    );

    /**
     * Breadcrumb Option
     */
    $wp_customize->add_setting(
        'quality_construction_breadcrumb_setting_option',
        array(
                'default' => $default['quality_construction_breadcrumb_setting_option'],
                'sanitize_callback' => 'quality_construction_sanitize_select',

             )
    );
    $hide_show_breadcrumb_option = quality_construction_show_breadcrumb_option();
    $wp_customize->add_control('quality_construction_breadcrumb_setting_option',
        array(
                'label' => esc_html__('Breadcrumb Options', 'quality-construction'),
                'description'   => sprintf( esc_html__( 'Advanced: Requires %1$sBreadcrumb NavXT%2$s plugin','quality-construction'), '<a href="https://wordpress.org/plugins/breadcrumb-navxt/" target="_blank">','</a>' ),
                'section' => 'quality_construction_breadcrumb_option',
                'choices' => $hide_show_breadcrumb_option,
                'type' => 'select',
                'priority' => 10
              )
    );


    /**
     *   Show/Hide Breadcrumb in Home page
     */
    $wp_customize->add_setting(
        'quality_construction_hide_breadcrumb_front_page_option',
        array(
                'default' => $default['quality_construction_hide_breadcrumb_front_page_option'],
                'sanitize_callback' => 'quality_construction_sanitize_checkbox',
             )
    );
    $wp_customize->add_control('quality_construction_hide_breadcrumb_front_page_option',
        array(
                'label' => esc_html__('Show/Hide Breadcrumb in Home page', 'quality-construction'),
                'section' => 'quality_construction_breadcrumb_option',
                'type' => 'checkbox',
                'priority' => 10
             )
    );

    /*-------------------------------------------------------------------------------------------*/
    /**
     * Button Design
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_button_design_option',
        array(
                'title'		=> esc_html__( 'Button Design','quality-construction'),
                'panel'     => 'quality_construction_theme_options',
                'priority'  => 6,
             )
    );

    /**
     * Post Navigation Options
     */
    $wp_customize->add_setting(
        'quality_construction_button_design_layout_option',
        array(
                'default'           => $default['quality_construction_button_design_layout_option'],
                'sanitize_callback' => 'quality_construction_sanitize_select',
                'transport' => 'refresh'
              )
    );
    $button_design_option = quality_construction_button_design_option();
    $wp_customize->add_control('quality_construction_button_design_layout_option',
        array(
                'label'      => esc_html__('Button Design','quality-construction'),
                'section'   => 'quality_construction_button_design_option',
                'type'	  	=> 'select',
                'choices'   => $button_design_option,
                'priority'  => 11
             )
    );

    /*-------------------------------------------------------------------------------------------*/
    /**
     * Pagination Options
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_pagination_option',
        array(
                'title'		=> esc_html__('Pagination Options','quality-construction'),
                'panel'     => 'quality_construction_theme_options',
                'priority'  => 12,
             )
    );

    /**
     *Pagination Options
     */
    $wp_customize->add_setting(
        'quality_construction_post_pagination_option',
        array(
                'default'           =>  $default['quality_construction_post_pagination_option'],
                'sanitize_callback' => 'sanitize_text_field',
                'transport' => 'refresh'
             )
    );
    $pagination_option = quality_construction_pagination_option();
    $wp_customize->add_control('quality_construction_post_pagination_option',
        array(
                'label'      => esc_html__('Pagination Options','quality-construction'),
                'description'    => sprintf( esc_html__( 'Blog and Archive Pages Pagination', 'quality-construction' )),
                'section'   => 'quality_construction_pagination_option',
                'type'	  	=> 'select',
                'choices'   => $pagination_option,
                'priority'  => 12
             )
    );

    /*-------------------------------------------------------------------------------------------*/
    /**
     * Search Placeholder
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_search_option',
        array(
                'title' => esc_html__('Search', 'quality-construction'),
                'panel' => 'quality_construction_theme_options',
                'priority' => 12,
              )
    );

    /**
     *Search Placeholder
     */
    $wp_customize->add_setting(
        'quality_construction_post_search_placeholder_option',
        array(
                'default' => $default['quality_construction_post_search_placeholder_option'],
                'sanitize_callback' => 'sanitize_text_field',

              )
    );

    $wp_customize->add_control('quality_construction_post_search_placeholder_option',
        array(
                'label' => esc_html__('Search Placeholder', 'quality-construction'),
                'section' => 'quality_construction_search_option',
                'type' => 'text',
                'priority' => 10
              )
    );


     /*-------------------------------------------------------------------------------------------*/
    /**
     * Contact Us
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_contact_us_option',
        array(
                'title' => esc_html__('Contact Us Options', 'quality-construction'),
                'panel' => 'quality_construction_theme_options',
                'priority' => 12,
              )
    );

    /**
     *Contact Us Working Hours
     */
    $wp_customize->add_setting(
        'quality_construction_working_hours_option',
        array(
                'default' => $default['quality_construction_working_hours_option'],
                'sanitize_callback' => 'wp_kses_post',

              )
    );

    $wp_customize->add_control('quality_construction_working_hours_option',
        array(
                'label' => esc_html__('Working Hours', 'quality-construction'),
                'description'   => sprintf( esc_html__( 'Insert Working Hours with html tag.[It will work only on Contact Us Template]','quality-construction')),
                'section' => 'quality_construction_contact_us_option',
                'type' => 'textarea',
                'priority' => 10
              )
    );


    /**
     *Contact Information
     */
    $wp_customize->add_setting(
        'quality_construction_contact_info_option',
        array(
                'default' => $default['quality_construction_contact_info_option'],
                'sanitize_callback' => 'wp_kses_post',

              )
    );

    $wp_customize->add_control('quality_construction_contact_info_option',
        array(
                'label' => esc_html__('Connect With Us', 'quality-construction'),
                'description'   => sprintf( esc_html__( 'Insert Contact Info with html tag.[It will work only on Contact Us Template]','quality-construction')),
                'section' => 'quality_construction_contact_us_option',
                'type' => 'textarea',
                'priority' => 10
              )
    );


    /**
     *Contact Us Google Map Iframe
     */
    $wp_customize->add_setting(
        'quality_construction_googlemap_option',
        array(
                'default' => $default['quality_construction_googlemap_option'],
                'sanitize_callback' => 'quality_construction_sanitize_iframe',

              )
    );

    $wp_customize->add_control('quality_construction_googlemap_option',
        array(
                'label' => esc_html__('Google Map Iframe', 'quality-construction'),
                'description'   => sprintf( esc_html__( 'Insert Google Map Iframe.[It will work only on Contact Us Template]','quality-construction')),
                'section' => 'quality_construction_contact_us_option',
                'type' => 'textarea',
                'priority' => 10
              )
    );




    /*-------------------------------------------------------------------------------------------*/
    /**
     * Reset Options
     *
     * @since 1.0.0
     */
    $wp_customize->add_section(
        'quality_construction_reset_option',
        array(
                'title' => esc_html__('Color Reset Options', 'quality-construction'),
                'panel' => 'quality_construction_theme_options',
                'priority' => 14,
             )
    );

    /**
     * Reset Option
     */
    $wp_customize->add_setting(
        'quality_construction_color_reset_option',
        array(
                'default' => $default['quality_construction_color_reset_option'],
                'sanitize_callback' => 'quality_construction_sanitize_select',
                'transport' => 'postMessage'
             )
    );
    $reset_option = quality_construction_reset_option();
    $wp_customize->add_control('quality_construction_color_reset_option',
        array(
                'label' => esc_html__('Reset Options', 'quality-construction'),
                'description' => sprintf( esc_html__('Caution: Reset theme settings according to the given options. Refresh the page after saving to view the effects', 'quality-construction')),
                'section' => 'quality_construction_reset_option',
                'type' => 'select',
                'choices' => $reset_option,
                'priority' => 20
             )
    );