<?php
if (!class_exists('Quality_Construction_About_Us_Widget'))
{
    class Quality_Construction_About_Us_Widget extends WP_Widget
    {
        private function defaults()
        {
            $defaults = array(
                'page_id' => '',
                'title' => esc_html__('Our Story','quality-construction'),
                'button-text' => esc_html__('Read More','quality-construction'),
                'button-text-link' => '#',
                'image-alignment' => 'left',
            );
            return $defaults;
        }

        public function __construct()
        {
            parent::__construct(
                'quality-construction-about-us-widget',
                esc_html__('Quality Construction About Us Page', 'quality-construction'),
                array('description' => esc_html__('Quality Construction About Us Page', 'quality-construction'))
            );
        }

        public function widget($args, $instance)
        {
            if (!empty($instance)) {
                $instance = wp_parse_args((array)$instance, $this->defaults());
                $page_id = absint($instance['page_id']);
                $title = apply_filters('widget_title', !empty($instance['title']) ? esc_html($instance['title']) : '', $instance, $this->id_base);
                $button_text = esc_html($instance['button-text']);
                $button_url = esc_url($instance['button-text-link']);
                $image_alignment = esc_attr($instance['image-alignment']);
                echo $args['before_widget'];
                ?>

                <section id="section18" class="section-margine section18 <?php echo esc_attr($image_alignment) ?>">
                    <div class="container">
                        <div class="row">
                            <?php
                            $quality_construction_page_args = array(
                                'page_id' => $page_id,
                                'posts_per_page' => 1,
                                'post_type' => 'page',
                                'no_found_rows' => true,
                                'post_status' => 'publish'
                            );
                            $about_us_query = new WP_Query($quality_construction_page_args);
                            if ($about_us_query->have_posts()):
                                while ($about_us_query->have_posts()):$about_us_query->the_post();
                                    if(has_post_thumbnail())
                                    {
                                      $image_id = get_post_thumbnail_id();
                                   
                                    $image_url = wp_get_attachment_image_src($image_id, 'full', true);
                                    $image_path = $image_url[0];

                                    ?>
                                      <div class="col-md-5 wow fadeInLeft  <?php echo $image_alignment; ?>">
                                        <div class="section-18-img">
                                            <img src="<?php echo esc_url($image_path); ?>" class="img-responsive" alt=""/>
                                        </div>
                                      </div>
                                   <?php   } ?>   
                                    <div class=" <?php if(has_post_thumbnail()){ echo "col-md-7 "; } else { echo "col-md-12"; } ?> wow fadeInRight">
                                        <div class="textcont">
                                            <h2><?php echo $title; ?></h2>
                                            <p><?php echo (substr(get_the_content(),0, 500)); ?></p>
                                            <a href="<?php echo $button_url; ?>" class="btn btn-primary">
                                                <?php echo $button_text; ?> 
                                            </a>
                                        </div>
                                    </div>
                                    <?php
                                endwhile;
                              wp_reset_postdata();
                            endif;
                            ?>

                        </div>
                    </div>
                </section>
            <?php
                echo $args['after_widget'];
            }
        }

        public function update($new_instance, $old_instance)
        {
            $instance = $old_instance;
            $instance['title'] = sanitize_text_field($new_instance['title']);
            $instance['page_id'] = absint($new_instance['page_id']);
            $instance['button-text'] = sanitize_text_field($new_instance['button-text']);
            $instance['button-text-link'] = esc_url_raw($new_instance['button-text-link']);
            $instance['image-alignment'] = sanitize_text_field($new_instance['image-alignment']);
            return $instance;
        }

        public function form($instance)
        {
            $instance = wp_parse_args((array )$instance, $this->defaults());
            $page_id = absint($instance['page_id']);
            $title = esc_attr($instance['title']);
            $button_text = esc_attr($instance['button-text']);
            $button_url = esc_url($instance['button-text-link']);
            $image_alignment = esc_attr($instance['image-alignment']);

            ?>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><?php esc_html_e('Title', 'quality-construction'); ?></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" value="<?php echo $title ?>">
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('page_id') ); ?>"><strong><?php esc_html_e('Select Page', 'quality-construction'); ?></strong></label><br/>
                <?php
                /* see more here https://codex.wordpress.org/Function_Reference/wp_dropdown_pages*/
                $args = array(
                    'selected' => $page_id,
                    'name' => esc_attr($this->get_field_name('page_id')),
                    'id' => esc_attr($this->get_field_id('page_id')),
                    'class' => 'widefat',
                    'show_option_none' => esc_attr__('Select Page', 'quality-construction'),
                );
                wp_dropdown_pages($args);
                ?>
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('button-text') ); ?>"><strong><?php esc_html_e('Button Text', 'quality-construction'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('button-text') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('button-text') ); ?>" value="<?php echo $button_text; ?>">
            </p>
            <hr>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('button-text-link') ); ?>"><strong><?php esc_html_e('Button Link', 'quality-construction'); ?></strong></label><br/>
                <input type="url" name="<?php echo esc_attr( $this->get_field_name('button-text-link') ); ?>" id="<?php echo esc_attr( $this->get_field_id('button-text-link') ); ?>" class="widefat"  value="<?php echo $button_url; ?>">
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('image-alignment')); ?>"><strong><?php esc_html_e('Feature Image Alignment:', 'quality-construction'); ?></strong></label>
                <?php
                $this->dropdown_image_alignment(array(
                        'id' => esc_attr($this->get_field_id('image-alignment')),
                        'name' => esc_attr($this->get_field_name('image-alignment')),
                        'selected' => $image_alignment
                    )
                );
                ?>
            </p>
        <?php
        }

        function dropdown_image_alignment($args)
        {
            $defaults = array(
                                'id' => '',
                                'name' => '',
                                'selected' => 0,
                              );

            $r = wp_parse_args($args, $defaults);
            $output = '';

            $choices = array(
                            'left' => __('Left', 'quality-construction'),
                            'right' => __('Right', 'quality-construction')
                            );

            if (!empty($choices))
            {

                $output = "<select name='" . esc_attr($r['name']) . "' id='" . esc_attr($r['id']) . "'>\n";
                foreach ($choices as $key => $choice) {
                    $output .= '<option value="' . esc_attr($key) . '" ';
                    $output .= selected($r['selected'], $key, false);
                    $output .= '>' . esc_html($choice) . '</option>\n';
                }
                $output .= "</select>\n";
            }

            echo $output;
        }

    }

}
add_action('widgets_init', 'quality_construction_about_us_widget');
function quality_construction_about_us_widget()
{
    register_widget('Quality_Construction_About_Us_Widget');

}















