<?php
if (!class_exists('Quality_Construction_Counter_Widget'))
{
    class Quality_Construction_Counter_Widget extends WP_Widget
    {
        private function defaults()
        {
            $defaults = array(
                'icon-class_First'     => 'fa-group',
                'counter-value_First'  => 10,
                'symbol_First'         => '+',
                'title_First'          => esc_html__( 'Clients','quality-construction'),
                
                'icon-class_Second'    => 'fa-glass',
                'counter-value_Second' => 15,
                'symbol_Second'        => '+',
                'title_Second'         => esc_html__( 'Winner','quality-construction'),
                
                'icon-class_Third'     => 'fa-desktop',
                'counter-value_Third'  => 20,
                'symbol_Third'         => '+',
                'title_Third'          => esc_html__( 'Projects','quality-construction'),
                
                'icon-class_Fourth'    => 'fa-star',
                'counter-value_Fourth' => 25,
                'symbol_Fourth'        => '%',
                'title_Fourth'         => esc_html__( 'Rating','quality-construction'),
                'background-image'     => '',
            );
            return $defaults;
        }

        public function __construct()
        {
            parent::__construct(
                'quality-construction-counter-widget',
                esc_html__('Quality Construction Counter Widget', 'quality-construction'),
                array('description' => esc_html__('Quality Construction Counter Section', 'quality-construction'))
            );
        }

        public function widget($args, $instance)
        {

            if (!empty($instance)) {
                $instance = wp_parse_args((array)$instance, $this->defaults());
                $bgimage = esc_attr($instance[ 'background-image']);
                echo $args['before_widget'];
                ?>

                <section id="section3" class="section-margine section3-background"   style="<?php if(!empty($bgimage)) { ?>background: url(<?php echo $bgimage; ?>) repeat;<?php } else { ?> background: #143646;  <?php } ?>">
                    <div class="container">
                        <div class="row">
                            <?php
                            $count = 0;
                            $counter = array('First', 'Second', 'Third', 'Fourth');
                            foreach ($counter as $counter_value)
                                {
                                    $icon  = $instance['icon-class_' . $counter_value];
                                    $value = $instance['counter-value_' . $counter_value];
                                    $title = $instance['title_' . $counter_value];


                                    if (!empty($icon) && !empty($value) && !empty($title))
                                    {
                                        $count = $count + 1;
                                    }
                                }

                            foreach ($counter as $counter_value)
                            {
                                  $icon   = $instance['icon-class_' . $counter_value];
                                  $value  = $instance['counter-value_' . $counter_value];
                                  $title  = $instance['title_' . $counter_value];
                                  $symbol = $instance['symbol_' . $counter_value];
                                  $colsm  = "";
                                if (!empty($icon) && !empty($value) && !empty($title))
                                {
                                    if ($count == 4)
                                    {
                                        $colsm = 3;
                                    } elseif ($count == 3)
                                    {
                                        $colsm = 4;
                                    } elseif ($count == 2)
                                    {
                                        $colsm = 6;
                                    } elseif ($count == 1)
                                    {
                                        $colsm = 12;
                                    }

                                    ?>
                                    <div class="col-md-<?php echo esc_attr( $colsm ); ?>">
                                        <div class="section-3-box wow fadeInUp">
                                            <figure><i class="fa <?php echo esc_attr( $icon ); ?> fa-2x"></i></figure>
                                            <h3><span class="counter"><?php echo esc_html( $value ); ?></span><?php echo esc_html($symbol) ?></h3>
                                            <h4><?php echo esc_html( $title ); ?></h4>
                                        </div>
                                    </div>
                                <?php }
                            } ?>

                        </div>
                    </div>
                </section>

                <?php
                echo $args['after_widget'];
            }
        }

        public function update($new_instance, $old_instance)
        {
            $instance = $old_instance;
            $counter = array('First', 'Second', 'Third', 'Fourth');
            foreach ($counter as $counter_value)
            {
                $instance['icon-class_' . $counter_value]    = sanitize_text_field( $new_instance['icon-class_' . $counter_value] );
                $instance['counter-value_' . $counter_value] = absint($new_instance['counter-value_' . $counter_value]);
                $instance['symbol_' . $counter_value]        = sanitize_text_field( $new_instance['symbol_' . $counter_value]);
                $instance['title_' . $counter_value]         = sanitize_text_field($new_instance['title_' . $counter_value]);

            }
            $instance['background-image'] = esc_url_raw($new_instance['background-image']);
            return $instance;
        }

        public function form($instance)
        {
            $instance = wp_parse_args((array )$instance, $this->defaults());
            $counters = array('First', 'Second', 'Third', 'Fourth');
             $i = 0;
            $bgimage = esc_attr($instance['background-image']);
            foreach ( $counters as $countervalue )
            {
                $icon   = $instance['icon-class_' . $countervalue];
                $value  = $instance['counter-value_' . $countervalue];
                $title  = $instance['title_' . $countervalue];
                $symbol = $instance['symbol_' . $countervalue];

                ?>

                <p>
                    <label for="<?php echo esc_attr( $this->get_field_id('icon-class_'. $countervalue) ); ?>"><strong><?php echo esc_html__( $countervalue . ' Font Awesome Class ','quality-construction'); ?></strong></label><br/>
                    <small>
                      <strong>
                        <?php
                        esc_html_e( 'Font Awesome Icon Used in Widgets', 'quality-construction');
                        printf( __( '%1$sRefer here%2$s for icon class. For example: %3$sfa-desktop%4$s', 'quality-construction'), '<br /><a href="'.esc_url( 'http://fontawesome.io/cheatsheet/' ).'" target="_blank">','</a>',"<code>","</code>" );
                        ?>
                      </strong>  
                    </small>
                    <br/>
                    <input type="text" name="<?php echo esc_attr( $this->get_field_name('icon-class_'. $countervalue) ); ?>" id="<?php echo esc_attr( $this->get_field_id('icon-class_'. $countervalue) ); ?>" class="widefat" value="<?php echo esc_attr( $icon ); ?>">
                </p>
                <hr>
                <p>
                    <label for="<?php echo  esc_attr( $this->get_field_id('counter-value_' . $countervalue) ); ?>"><strong><?php echo esc_html__($countervalue . ' Counter Value in Number','quality-construction'); ?></strong></label><br/>
                    <input type="number" name="<?php echo esc_attr( $this->get_field_name('counter-value_' . $countervalue) ); ?>" class="widefat" id="<?php echo  esc_attr( $this->get_field_id('counter-value_' . $countervalue) ); ?>"  value="<?php echo esc_attr( $value ); ?>"/>
                </p>
                <hr>

                <p>
                    <label for="<?php echo esc_attr( $this->get_field_id('symbol_' . $countervalue) ); ?>"><strong><?php echo esc_html__($countervalue . ' Symbol like +,%..','quality-construction'); ?></strong></label><br/>
                    <input type="text" name="<?php echo esc_attr( $this->get_field_name('symbol_' . $countervalue) ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('symbol_' . $countervalue) ); ?>"  value="<?php echo esc_attr( $symbol );  ?>">
                </p>
                <hr>

                <p>
                    <label for="<?php echo esc_attr( $this->get_field_id('title_' . $countervalue) ); ?>"><strong><?php echo esc_html__($countervalue . '  Title of Counter', 'quality-construction'); ?></strong></label><br/>
                    <input type="text" name="<?php echo esc_attr( $this->get_field_name('title_' . $countervalue) ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('title_' . $countervalue) ); ?>" value="<?php echo esc_attr( $title );   ?>">
                </p>
                <hr>
                <?php
                $i++;
            }
            ?>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('background-image') ); ?>">
                    <strong><?php echo esc_html__('Background Image', 'quality-construction'); ?></strong>
                </label>
                <br/>
                <?php
                    echo '<img class="custom_media_image" src="' . esc_url($instance['background-image']) . '" style="margin:0;padding:0;max-width:100px;float:left;display:inline-block" /><br />';
                 ?>

                
                <input type="text" class="widefat" name="<?php echo $this->get_field_name('background-image'); ?>" id="<?php echo $this->get_field_id('background-image'); ?>" value="<?php echo esc_url( $bgimage ); ?>" />
                <input type="button" value="<?php _e( 'Upload Image', 'quality-construction'); ?>" class="button media-image-upload" data-title="<?php _e( 'Select Background Image','quality-construction'); ?>" data-button="<?php _e( 'Select Background Image','quality-construction'); ?>"/>
                <input type="button" value="<?php _e( 'Remove Background Image', 'quality-construction'); ?>" class="button media-image-remove" />


            </p>

        <?php }
    }
}

add_action( 'widgets_init', 'quality_construction_counter_widget' );
function quality_construction_counter_widget(){
    register_widget( 'Quality_Construction_Counter_Widget' );

}















