<?php
if( !class_exists( 'Quality_Construction_Feature_Widget') )
{

    class Quality_Construction_Feature_Widget extends WP_Widget
    {
        private function defaults()
        {
            $defaults = array(
                'cat_id'          => 0,
                'character_limit' => 8,
                'post_column'     => 3,
                'post_number'     => 3,
            );
            return $defaults;
        }
        public function __construct()
        {
            parent::__construct(
                'quality-construction-feature-widget',
                esc_html__('Quality Construction Feature Widget', 'quality-construction'),
                array('description' => esc_html__('Quality Construction Feature Section', 'quality-construction'))
            );
        }

        public function widget($args, $instance)
        {
            if ( !empty( $instance ) )
            {
                $instance        = wp_parse_args( (array) $instance, $this->defaults() );
                /*default values*/
                $catid           = absint( $instance[ 'cat_id' ] );
                $limit_character = absint( $instance['character_limit'] );
                $column_number   = absint( $instance['post_column'] );
                $post_number     = absint( $instance['post_number'] );
                echo $args['before_widget'];
                ?>
                <section id="section1" class="section-margine">
                    <div class="container">
                        <div class="row">
                            <?php if ( !empty( $catid ) )
                            {
                                $i = 0;
                                $sticky = get_option( 'sticky_posts' );
                                $home_feature_section = array(
                                    'ignore_sticky_posts' => true,
                                    'post__not_in'        => $sticky,
                                    'cat'                 => $catid,
                                    'posts_per_page'      =>  $post_number
                                );
                                $home_feature_section_query = new WP_Query( $home_feature_section );
                                if ( $home_feature_section_query->have_posts() )
                                {
                                       if (2 == $column_number)
                                            {
                                                $quality_construction_column = "col-md-6";
                                            } elseif (3 == $column_number)
                                            {
                                                $quality_construction_column = "col-md-4";
                                            } elseif (4 == $column_number)
                                            {
                                                $quality_construction_column = 'col-md-3';
                                            }
                                            else
                                            {
                                                $quality_construction_column = 'col-md-12';
                                            }


                                    while ($home_feature_section_query->have_posts())
                                    {
                                        $home_feature_section_query->the_post();
                                        $icon = get_post_meta( get_the_ID(), 'quality_construction_icon', true );

                                        ?>
                                        <div class="<?php echo esc_attr($quality_construction_column); ?>">
                                            <div class="section-1-box wow bounceIn"
                                                 data-wow-delay=".<?php echo esc_attr($i); ?>">
                                                <?php
                                                if(!empty($icon))
                                                {
                                                    ?>
                                                    <div class="section-1-box-icon-background">
                                                        <i class="fa <?php echo esc_attr($icon); ?> fa-4x"></i>
                                                    </div>
                                                <?php } ?>
                                                <h4 class="text-left"><?php the_title() ?></h4>
                                                <p class="text-left"><?php echo esc_html( wp_trim_words( get_the_content(),$limit_character) ); ?></p>
                                            </div>
                                        </div>
                                        <?php
                                        $i++;
                                    }
                                }
                                wp_reset_postdata();
                            }
                            ?>
                        </div>
                    </div>
                </section>
                <?php
                echo $args['after_widget'];
            }
        }

        public function update($new_instance, $old_instance)
        {
            $instance                    = $old_instance;
            $instance['cat_id']          = (isset($new_instance['cat_id'])) ? absint( $new_instance['cat_id'] ) : '';
            $instance['character_limit'] = absint( $new_instance['character_limit'] );
            $instance['post_number']     = absint( $new_instance['post_number'] );
            $instance['post_column']     = absint( $new_instance['post_column']);
            return $instance;

        }

        public function form($instance)
        {
            $instance                          = wp_parse_args( (array) $instance, $this->defaults() );
            /*default values*/
            $quality_construction_selected_cat = absint( $instance[ 'cat_id' ] );
            $limit_character                   = absint( $instance['character_limit'] );
            $post_number                       = absint($instance['post_number']);
            $column_number                     = absint($instance['post_column']);
            ?>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('cat_id') ); ?>">
                    <strong><?php esc_html_e('Select Category','quality-construction'); ?></strong>
                </label><br/>
                <?php
                $quality_construction_dropown_cat = array(
                    'show_option_none' => esc_html__('Select Category','quality-construction'),
                    'orderby'          => 'name',
                    'order'            => 'asc',
                    'show_count'       => 1,
                    'hide_empty'       => 1,
                    'echo'             => 1,
                    'selected'         => $quality_construction_selected_cat,
                    'hierarchical'     => 1,
                    'name'             => esc_attr( $this->get_field_name('cat_id') ),
                    'id'               => esc_attr( $this->get_field_name('cat_id') ),
                    'class'            => 'widefat',
                    'taxonomy'         => 'category',
                    'hide_if_empty'    => false,
                );
                wp_dropdown_categories($quality_construction_dropown_cat);
                ?>
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('post_number')); ?>"><strong><?php esc_html_e('Number of Posts:','quality-construction'); ?></strong></label>
                <input class="widefat" id="<?php echo esc_attr($this->get_field_id('post_number')); ?>" name="<?php echo esc_attr($this->get_field_name('post_number')); ?>" type="number" value="<?php echo $post_number; ?>" min="1"/>
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr($this->get_field_id('post_column')); ?>"><strong><?php esc_html_e('Number of Columns:', 'quality-construction'); ?></strong></label>
                <?php
                $this->dropdown_post_columns(
                    array(
                        'id' => esc_attr($this->get_field_id('post_column')),
                        'name' => esc_attr($this->get_field_name('post_column')),
                        'selected' => $column_number
                    )
                );
                ?>
            </p>
            <hr>
            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('character_limit')); ?>"><strong><?php esc_html_e('Character Limit', 'quality-construction'); ?></strong></label><br/>
                <input type="number" name="<?php echo esc_attr( $this->get_field_name('character_limit')); ?>" class="quality-cons" id="<?php echo esc_attr( $this->get_field_id('character_limit')); ?>" value="<?php echo $limit_character ?>">
            </p>
            <?php
        }

         function dropdown_post_columns($args)
        {
            $defaults = array(
                'id'       => '',
                'name'     => '',
                'selected' => 0,
            );

            $r = wp_parse_args($args, $defaults);
            $output = '';

            $choices = array(
                2 => esc_html__('2', 'quality-construction'),
                3 => esc_html__('3', 'quality-construction'),
                4 => esc_html__('4', 'quality-construction'),
            );

            if (!empty($choices))
            {

                $output = "<select name='" . esc_attr($r['name']) . "' id='" . esc_attr($r['id']) . "'>\n";
                foreach ($choices as $key => $choice) {
                    $output .= '<option value="' . esc_attr($key) . '" ';
                    $output .= selected($r['selected'], $key, false);
                    $output .= '>' . esc_html($choice) . '</option>\n';
                }
                $output .= "</select>\n";
            }

            echo $output;
        }
    }
}

add_action('widgets_init', 'quality_construction_feature_widget');
function quality_construction_feature_widget()
{
    register_widget('Quality_Construction_Feature_Widget');
}