<?php
if (!class_exists('Quality_Construction_Hero_Widget'))
{
    class Quality_Construction_Hero_Widget extends WP_Widget
    {

        private function defaults()
        {
            $defaults = array(
                'title'            => esc_html__('Quality Construction HTML Template. Buy this theme.', 'quality-construction'),
                'description'      => esc_html__('Create beautiful, unique websites with impact full landing pages and banners.', 'quality-construction'),
                'button-text'      => esc_html__('Get Started!', 'quality-construction'),
                'button-text-link' => '#'
               );

            return $defaults;
        }

        public function __construct()
        {
            parent::__construct(
                'quality-construction-hero-widget',
                esc_html__('Quality Construction Hero Widget', 'quality-construction'),
                array('description' => esc_html__('Quality Construction Hero Section', 'quality-construction'))
            );
        }

        public function widget($args, $instance)
        {
            if (!empty($instance)) {
                $instance    = wp_parse_args((array)$instance, $this->defaults());
                $title       = apply_filters('widget_title', !empty($instance['title']) ? esc_html($instance['title']) : '', $instance, $this->id_base);
                $description = wp_kses_post($instance['description']);
                $button_text = esc_html($instance['button-text']);
                $button_url  = esc_url($instance['button-text-link']);
                echo $args['before_widget'];
                ?>
                <section id="section10" class="section-10-background">
                    <div class="container">
                        <div class="row">
                            <div class="col-md-9">
                                <div class="section-10-box-text-cont">
                                    <h3><?php echo  $title ; ?></h3>
                                    <p><?php echo $description; ?></p>
                                </div>
                            </div>
                            <?php if(!empty($button_text)){ ?>
                            <div class="col-md-3">
                                <div class="section-10-btn-cont">
                                    <a href="<?php echo $button_url ; ?>" class="btn btn-seconday wow tada"><?php echo  $button_text; ?></a>
                                </div>
                            </div>
                         <?php } ?>   
                        </div>
                    </div>
                </section>
                <?php
                echo $args['after_widget'];
            }
        }

        public function update($new_instance, $old_instance)
        {
            $instance                     = $old_instance;
            $instance['title']            = sanitize_text_field($new_instance['title']);
            $instance['description']      = wp_kses_post($new_instance['description']);
            $instance['button-text']      = sanitize_text_field($new_instance['button-text']);
            $instance['button-text-link'] = esc_url_raw($new_instance['button-text-link']);
            return $instance;
        }

        public function form($instance)
        {
            $instance    = wp_parse_args((array )$instance, $this->defaults());
            $title       = esc_attr($instance['title']);
            $description = wp_kses_post($instance['description']);
            $button_text = esc_attr($instance['button-text']);
            $button_url  = esc_url($instance['button-text-link']);
            ?>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('title') ); ?>"><strong><?php esc_html_e('Title', 'quality-construction'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('title') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('title') ); ?>" value="<?php echo  $title; ?>">
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('description' ) ); ?>"><strong><?php esc_html_e('Description', 'quality-construction'); ?></strong></label><br/>
                <textarea rows="8" name="<?php echo esc_attr( $this->get_field_name('description') ); ?>" id="<?php echo esc_attr( $this->get_field_id('description' ) ); ?>" class="widefat"><?php echo $description; ?></textarea>
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('button-text') ); ?>"><strong><?php esc_html_e('Button Text', 'quality-construction'); ?></strong></label><br/>
                <input type="text" name="<?php echo esc_attr( $this->get_field_name('button-text') ); ?>" class="widefat" id="<?php echo esc_attr( $this->get_field_id('button-text') ); ?>" value="<?php echo $button_text; ?>">
            </p>

            <p>
                <label for="<?php echo esc_attr( $this->get_field_id('button-text-link') ); ?>"><strong><?php esc_html_e('Button Link', 'quality-construction'); ?></strong></label><br/>
                <input type="url" name="<?php echo esc_attr( $this->get_field_name('button-text-link') ); ?>" class="widefat"  id="<?php echo esc_attr( $this->get_field_id('button-text-link') ); ?>" value="<?php echo $button_url; ?>">
            </p>
            <?php
        }
    }

}

add_action( 'widgets_init', 'quality_construction_hero_widget' );
function quality_construction_hero_widget(){
    register_widget( 'Quality_Construction_Hero_Widget' );

}















